"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const kyso_command_1 = require("./kyso-command");
class Config extends kyso_command_1.KysoCommand {
    async run() {
        const { flags } = await this.parse(Config);
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        let fixedKysoInstallUrl;
        if (flags.kysoInstallUrl) {
            fixedKysoInstallUrl = flags.kysoInstallUrl;
        }
        else {
            const kysoApiResponse = await inquirer_1.default.prompt([
                {
                    name: 'kysoInstallUrl',
                    message: 'What is the url of your kyso installation?',
                    type: 'input',
                    default: (kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.fixedKysoInstallUrl) || (kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.kysoInstallUrl) || 'https://',
                    validate(url) {
                        if (url === '') {
                            return 'Url cannot be empty';
                        }
                        return true;
                    },
                    filter: (input) => {
                        if (input.endsWith('/')) {
                            input = input.slice(0, -1);
                        }
                        return input.trim();
                    },
                },
            ]);
            fixedKysoInstallUrl = kysoApiResponse.kysoInstallUrl;
        }
        kyso_command_1.KysoCommand.saveToken(kysoCredentials.token, kysoCredentials.organization, kysoCredentials.team, kysoCredentials.kysoInstallUrl, kysoCredentials.username, fixedKysoInstallUrl);
    }
}
exports.default = Config;
Config.description = 'Login into Kyso';
Config.examples = [
    `# Direct login using kyso provider and password
    $ kyso config --kysoInstallUrl <kyso_installation_url>`,
];
Config.flags = {
    kysoInstallUrl: core_1.Flags.string({
        char: 'y',
        description: 'Url of your Kyso installation',
        required: false,
        multiple: false,
    }),
};
Config.args = [];
