"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable indent */
const kyso_model_1 = require("@kyso-io/kyso-model");
const kyso_store_1 = require("@kyso-io/kyso-store");
const core_1 = require("@oclif/core");
const interactive_login_1 = require("../helpers/interactive-login");
const kyso_command_1 = require("./kyso-command");
class ImportRepository extends kyso_command_1.KysoCommand {
    async run() {
        const { flags } = await this.parse(ImportRepository);
        if (flags.verbose) {
            this.log('Enabled verbose mode');
            this.enableVerbose();
        }
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        this.log(`Importing ${flags.provider} repository ${flags.name}. Will take a while...`);
        const args = {
            repositoryName: flags.name,
        };
        if (flags.branch) {
            args.branch = flags.branch;
        }
        let result = null;
        switch (flags.provider) {
            case kyso_model_1.RepositoryProvider.GITHUB: {
                result = await kyso_store_1.store.dispatch((0, kyso_store_1.importGithubRepositoryAction)(args));
                break;
            }
            case kyso_model_1.RepositoryProvider.BITBUCKET: {
                result = await kyso_store_1.store.dispatch((0, kyso_store_1.importBitbucketRepositoryAction)(args));
                break;
            }
            case kyso_model_1.RepositoryProvider.GITLAB: {
                result = await kyso_store_1.store.dispatch((0, kyso_store_1.importGitlabRepositoryAction)(args));
                break;
            }
        }
        if (result === null || result === void 0 ? void 0 : result.error) {
            this.error(result.error.message);
        }
        else {
            this.log(`Successfully uploaded report`);
        }
        if (flags.verbose) {
            this.log('Disabling verbose mode');
            this.disableVerbose();
        }
    }
}
exports.default = ImportRepository;
ImportRepository.description = 'Import repository to Kyso';
ImportRepository.examples = [
    `$ kyso import-repository --provider github --name <repository_name> --branch <branch>`,
    `$ kyso import-repository --provider bitbucket --name <workspace/repository-name> --branch <branch>`,
    `$ kyso import-repository --provider gitlab --name <id | name_with_namespace> --branch <branch>`,
];
ImportRepository.flags = {
    provider: core_1.Flags.string({
        char: 'p',
        description: 'provider',
        required: true,
        options: [kyso_model_1.RepositoryProvider.BITBUCKET, kyso_model_1.RepositoryProvider.GITLAB, kyso_model_1.RepositoryProvider.GITHUB],
    }),
    name: core_1.Flags.string({
        char: 'n',
        description: 'name',
        required: true,
    }),
    branch: core_1.Flags.string({
        char: 'b',
        description: 'branch',
        required: false,
    }),
    verbose: core_1.Flags.boolean({
        char: 'x',
        description: 'Verbose mode for debugging',
        required: false,
        default: false,
    }),
};
ImportRepository.args = [];
