"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.KysoCommand = void 0;
const tslib_1 = require("tslib");
/* eslint-disable max-params */
const kyso_store_1 = require("@kyso-io/kyso-store");
const core_1 = require("@oclif/core");
const dotenv = tslib_1.__importStar(require("dotenv"));
const fs_1 = require("fs");
const jwt_decode_1 = tslib_1.__importDefault(require("jwt-decode"));
const os_1 = require("os");
const path_1 = require("path");
const check_credentials_result_enum_1 = require("../types/check-credentials-result.enum");
dotenv.config({
    path: (0, path_1.join)(__dirname, '../../.env'),
});
class KysoCommand extends core_1.Command {
    constructor(argv, config) {
        super(argv, config);
        this.previousKysoCliVerbose = process.env.KYSO_CLI_VERBOSE;
        this.verbose = false;
    }
    enableVerbose() {
        this.previousKysoCliVerbose = process.env.KYSO_CLI_VERBOSE;
        this.verbose = true;
        process.env.KYSO_CLI_VERBOSE = 'true';
    }
    disableVerbose() {
        this.verbose = false;
        process.env.KYSO_CLI_VERBOSE = this.previousKysoCliVerbose;
    }
    static removeCredentials() {
        if ((0, fs_1.existsSync)(this.tokenFilePath)) {
            (0, fs_1.unlinkSync)(this.tokenFilePath);
        }
    }
    static getCredentials() {
        return (0, fs_1.existsSync)(this.tokenFilePath) ? JSON.parse((0, fs_1.readFileSync)(this.tokenFilePath, 'utf8').toString()) : null;
    }
    static saveToken(token, organization, team, kysoInstallUrl, username, fixedKysoInstallUrl) {
        (0, fs_1.mkdirSync)(this.DATA_DIRECTORY, { recursive: true });
        const kysoCredentials = { token, organization, team, kysoInstallUrl, username, fixedKysoInstallUrl };
        (0, fs_1.writeFileSync)(this.tokenFilePath, JSON.stringify(kysoCredentials));
    }
    static async checkCredentials() {
        const kysoCredentials = this.getCredentials();
        if (!kysoCredentials) {
            return check_credentials_result_enum_1.CheckCredentialsResultEnum.NOT_EXIST;
        }
        try {
            if (kysoCredentials.kysoInstallUrl) {
                process.env.KYSO_API = `${kysoCredentials.kysoInstallUrl}/api/v1`;
            }
            // Check token validity
            const decoded = (0, jwt_decode_1.default)(kysoCredentials.token);
            if (decoded.exp * 1000 >= new Date().getTime()) {
                kyso_store_1.store.dispatch((0, kyso_store_1.setTokenAuthAction)(kysoCredentials.token));
                kyso_store_1.store.dispatch((0, kyso_store_1.setOrganizationAuthAction)(kysoCredentials.organization));
                kyso_store_1.store.dispatch((0, kyso_store_1.setTeamAuthAction)(kysoCredentials.team));
                return check_credentials_result_enum_1.CheckCredentialsResultEnum.VALID;
            }
        }
        catch { }
        return check_credentials_result_enum_1.CheckCredentialsResultEnum.EXPIRED_TOKEN;
        // this.removeCredentials(kysoCredentials)
    }
}
exports.KysoCommand = KysoCommand;
_a = KysoCommand;
KysoCommand.DATA_DIRECTORY = process.env.KYSO_DATA_DIRECTORY ? process.env.KYSO_DATA_DIRECTORY : (0, path_1.join)((0, os_1.homedir)(), '.kyso');
KysoCommand.args = [];
KysoCommand.tokenFilePath = (0, path_1.join)(_a.DATA_DIRECTORY, 'auth.json');
