"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/* eslint-disable no-prototype-builtins */
const core_1 = require("@oclif/core");
const fs_1 = require("fs");
const open_1 = tslib_1.__importDefault(require("open"));
const path_1 = require("path");
const helper_1 = require("../helpers/helper");
const kyso_command_1 = require("./kyso-command");
class Open extends kyso_command_1.KysoCommand {
    async run() {
        const { flags } = await this.parse(Open);
        if (flags.verbose) {
            this.log('Enabled verbose mode');
            this.enableVerbose();
        }
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        if (!kysoCredentials) {
            this.log(`No credentials found. Please login first.`);
        }
        if (!(0, fs_1.existsSync)(flags.path)) {
            this.error('Invalid path');
        }
        if (!(0, fs_1.lstatSync)(flags.path).isDirectory()) {
            this.error('Path must be a directory');
        }
        const basePath = (0, path_1.isAbsolute)(flags.path) ? flags.path : (0, path_1.join)('.', flags.path);
        const files = (0, fs_1.readdirSync)(basePath).map((file) => (0, path_1.join)(basePath, file));
        const { kysoConfigFile, valid, message } = helper_1.Helper.findKysoConfigFile(files);
        if (!valid) {
            this.error(`Could not open the report using Kyso config file: ${message}`);
        }
        if (!kysoConfigFile.hasOwnProperty('organization') || kysoConfigFile.organization === null || kysoConfigFile.organization.length === 0) {
            this.error('Kyso file does not defined the organization');
        }
        if (!kysoConfigFile.hasOwnProperty('team') || kysoConfigFile.team === null || kysoConfigFile.team.length === 0) {
            this.error('Kyso file does not defined the channel');
        }
        if (!kysoConfigFile.hasOwnProperty('title') || kysoConfigFile.title === null || kysoConfigFile.title.length === 0) {
            this.error('Kyso file does not defined the title');
        }
        let domain;
        if (!kysoCredentials) {
            const url = await helper_1.Helper.askUserKysoInstallUrl();
            domain = new URL(url);
        }
        else {
            domain = new URL(kysoCredentials.kysoInstallUrl);
        }
        const reportUrl = `${domain.protocol}//${domain.hostname}/${kysoConfigFile.organization}/${kysoConfigFile.team}/${helper_1.Helper.slug(kysoConfigFile.title)}`;
        this.log(`Opening "${reportUrl}" the in browser...`);
        await (0, open_1.default)(reportUrl);
        if (flags.verbose) {
            this.log('Disabling verbose mode');
            this.disableVerbose();
        }
    }
}
exports.default = Open;
Open.description = 'Open a report in the browser';
Open.examples = [`$ kyso open --path <report_path>`];
Open.flags = {
    path: core_1.Flags.string({
        char: 'p',
        description: "Folder's path in which kyso.json, yaml or yml file is placed",
        required: false,
        default: '.',
    }),
    verbose: core_1.Flags.boolean({
        char: 'x',
        description: 'Verbose mode for debugging',
        required: false,
        default: false,
    }),
};
Open.args = [];
