"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const kyso_store_1 = require("@kyso-io/kyso-store");
const axios_1 = tslib_1.__importDefault(require("axios"));
const fs_1 = require("fs");
const path_1 = require("path");
const helper_1 = require("../../../helpers/helper");
const interactive_login_1 = require("../../../helpers/interactive-login");
const kyso_command_1 = require("../../kyso-command");
class DownloadOrganizationPhoto extends kyso_command_1.KysoCommand {
    async run() {
        const { args } = await this.parse(DownloadOrganizationPhoto);
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        const api = new kyso_store_1.Api();
        api.configure(`${kysoCredentials.kysoInstallUrl}/api/v1`, kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.token);
        try {
            const result = await helper_1.Helper.getOrganizationFromSlugSecurely(args.organization, kysoCredentials);
            const organization = result.data;
            if (!organization.avatar_url) {
                this.log('Organization has no photo');
                return;
            }
            const imageUrl = organization.avatar_url.startsWith('http') ? organization.avatar_url : kysoCredentials.kysoInstallUrl + organization.avatar_url;
            const axiosResponse = await axios_1.default.get(imageUrl, { responseType: 'arraybuffer' });
            const urlParts = axiosResponse.request.res.responseUrl.split('/');
            if (urlParts.length === 0) {
                this.error('Error downloading photo');
            }
            const fileName = urlParts[urlParts.length - 1];
            if (!fileName.includes('.')) {
                this.error('User profile photo has no extension');
            }
            let downloadPathAndName;
            if (args.image_file) {
                downloadPathAndName = (0, path_1.resolve)(args.image_file);
            }
            else {
                downloadPathAndName = (0, path_1.resolve)((0, path_1.join)('.', fileName));
            }
            (0, fs_1.writeFileSync)(downloadPathAndName, axiosResponse.data, 'binary');
            this.log(`Photo downloaded to ${downloadPathAndName}`);
        }
        catch (e) {
            this.error('Error downloading photo');
        }
    }
}
exports.default = DownloadOrganizationPhoto;
DownloadOrganizationPhoto.description = 'Download the photo images of the given organization and save them on the provided image_file';
DownloadOrganizationPhoto.examples = [`$ kyso organization download photo <organization> <image_file>`];
DownloadOrganizationPhoto.args = [
    {
        name: 'organization',
        description: `Organization's slugified name`,
        required: true,
    },
    {
        name: 'image_file',
        description: 'Destination file name',
        required: false,
    },
];
