"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const kyso_model_1 = require("@kyso-io/kyso-model");
const kyso_store_1 = require("@kyso-io/kyso-store");
const axios_1 = tslib_1.__importDefault(require("axios"));
const fs_1 = require("fs");
const jsYaml = tslib_1.__importStar(require("js-yaml"));
const jwt_decode_1 = tslib_1.__importDefault(require("jwt-decode"));
const _ = tslib_1.__importStar(require("lodash"));
const path_1 = require("path");
const helper_1 = require("../../helpers/helper");
const interactive_login_1 = require("../../helpers/interactive-login");
const kyso_command_1 = require("../kyso-command");
class OrganizationsSet extends kyso_command_1.KysoCommand {
    async updatePhoto(api, organizationId, photoBase64) {
        if (!photoBase64.startsWith('data:image/')) {
            this.log('Error: Photo must be a base64 string');
            return;
        }
        try {
            // Create file from base64 string
            const formatImage = photoBase64.split(';')[0].split('/')[1];
            const imageFilePath = (0, path_1.join)(kyso_command_1.KysoCommand.DATA_DIRECTORY, `organization-${organizationId}-photo-${new Date().getTime()}.${formatImage}`);
            const buffer = Buffer.from(photoBase64.split(',')[1], 'base64');
            (0, fs_1.writeFileSync)(imageFilePath, buffer);
            const readStream = (0, fs_1.createReadStream)(imageFilePath);
            await api.uploadOrganizationImage(organizationId, readStream);
            (0, fs_1.unlinkSync)(imageFilePath);
        }
        catch (e) {
            this.log(`Error uploading photo: ${e.response.data.message}`);
        }
    }
    async updateOrganization(api, tokenPermissions, organizationData, kysoCredentials) {
        var _a, _b, _c, _d, _e;
        const indexOrganization = tokenPermissions.organizations.findIndex((resourcePermissionOrganization) => resourcePermissionOrganization.name === organizationData.slug);
        const resourcePermissions = tokenPermissions.organizations[indexOrganization];
        if (indexOrganization === -1 && !helper_1.Helper.isGlobalAdmin(tokenPermissions)) {
            this.log(`You don't belong to the organization ${organizationData.slug}`);
            return;
        }
        const isOrgAdmin = helper_1.Helper.isOrganizationAdmin(resourcePermissions);
        const isGlobalAdmin = helper_1.Helper.isGlobalAdmin(tokenPermissions);
        if (!isOrgAdmin && !isGlobalAdmin) {
            this.log(`You don't have permissions to get the information for the organization ${organizationData.slug}`);
            return;
        }
        let organization = null;
        let photoBase64 = null;
        try {
            const resultOrganization = await api.getOrganizationBySlug(organizationData.slug);
            organization = resultOrganization.data;
        }
        catch (e) {
            this.log(`Error: Organization ${organizationData.slug} does not exist`);
            return;
        }
        if (organization.avatar_url) {
            try {
                const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
                const imageUrl = organization.avatar_url.startsWith('http') ? organization.avatar_url : kysoCredentials.kysoInstallUrl + organization.avatar_url;
                const axiosResponse = await axios_1.default.get(imageUrl, { responseType: 'text', responseEncoding: 'base64' });
                if (axiosResponse.status === 200) {
                    photoBase64 = `data:${axiosResponse.headers['content-type']};base64,${axiosResponse.data}`;
                }
            }
            catch (e) {
                console.log(e);
            }
        }
        let updatedPhoto = false;
        if ((!photoBase64 && organizationData.photo) || (photoBase64 && organizationData.photo && photoBase64 !== organizationData.photo)) {
            await this.updatePhoto(api, organization.id, organizationData.photo);
            updatedPhoto = true;
        }
        const updateOrganizationDto = kyso_model_1.UpdateOrganizationDTO.createEmpty();
        if (organizationData.display_name && organizationData.display_name !== organization.display_name) {
            this.log(`Organization display_name changed from ${organization.display_name} to ${organizationData.display_name}`);
            updateOrganizationDto.display_name = organizationData.display_name;
        }
        else {
            updateOrganizationDto.display_name = organization.display_name;
        }
        if (organizationData.location && organizationData.location !== organization.location) {
            this.log(`Organization location changed from ${organization.location} to ${organizationData.location}`);
            updateOrganizationDto.location = organizationData.location;
        }
        else {
            updateOrganizationDto.location = organization.location;
        }
        if (organizationData.link && organizationData.link !== organization.link) {
            this.log(`Organization link changed from ${organization.link} to ${organizationData.link}`);
            updateOrganizationDto.link = organizationData.link;
        }
        else {
            updateOrganizationDto.link = organization.link;
        }
        if (organizationData.bio && organizationData.bio !== organization.bio) {
            this.log(`Organization bio changed from ${organization.bio} to ${organizationData.bio}`);
            updateOrganizationDto.bio = organizationData.bio;
        }
        else {
            updateOrganizationDto.bio = organization.bio;
        }
        if (organizationData.allowed_access_domains) {
            if (!organization.allowed_access_domains) {
                this.log(`Added new allowed access domains ${organizationData.allowed_access_domains.join(',')}`);
                updateOrganizationDto.allowed_access_domains = [...organizationData.allowed_access_domains];
            }
            else if (organization.allowed_access_domains.length !== organizationData.allowed_access_domains.length) {
                this.log(`Changed allowed access domains to ${organizationData.allowed_access_domains.join(',')}`);
                updateOrganizationDto.allowed_access_domains = [...organizationData.allowed_access_domains];
            }
            else {
                for (let i = 0; i < organization.allowed_access_domains.length; i++) {
                    if (organization.allowed_access_domains[i] !== organizationData.allowed_access_domains[i]) {
                        this.log(`Changed allowed access domains to ${organizationData.allowed_access_domains.join(',')}`);
                        updateOrganizationDto.allowed_access_domains = [...organizationData.allowed_access_domains];
                        break;
                    }
                }
            }
        }
        const options = kyso_model_1.OrganizationOptionsDTO.createEmpty();
        if ((_a = organizationData === null || organizationData === void 0 ? void 0 : organizationData.options) === null || _a === void 0 ? void 0 : _a.notifications) {
            const objectToCompare = { centralized: (_c = (_b = organization.options) === null || _b === void 0 ? void 0 : _b.notifications) === null || _c === void 0 ? void 0 : _c.centralized, emails: (_e = (_d = organization === null || organization === void 0 ? void 0 : organization.options) === null || _d === void 0 ? void 0 : _d.notifications) === null || _e === void 0 ? void 0 : _e.emails };
            if (!_.isEqual(organizationData.options.notifications, objectToCompare)) {
                if (organizationData.options.notifications.centralized && organizationData.options.notifications.emails.length === 0) {
                    // Centralized notifications activated but without any email. Show error and don't update
                    this.log('Warning: enabled centralized communications without any configured mail. This change will not be applied');
                }
                else {
                    options.notifications = new kyso_model_1.OrganizationNotificationsDTO(organizationData.options.notifications.centralized, organizationData.options.notifications.emails, '', '', '');
                }
            }
        }
        if (Object.keys(options).length > 0) {
            updateOrganizationDto.options = options;
        }
        // Check channels and create if not exists
        const unexistingChannels = [];
        for (const channelSlug of organizationData.channels) {
            try {
                await helper_1.Helper.getChannelFromSlugSecurely(organization, channelSlug, kysoCredentials, true);
            }
            catch (e) {
                // If an exception is raised means that the channel doesn't exists in that organization
                this.log(`Specified ${channelSlug} channel does not exist in organization ${organization.display_name}.`);
                unexistingChannels.push(channelSlug);
            }
        }
        if (unexistingChannels.length > 0) {
            this.log('\nTo create unexisting channels please run the following command');
            this.log(`    kyso channel add ${organization.sluglified_name} ${unexistingChannels.join(',')}\n`);
        }
        if (Object.keys(updateOrganizationDto).length > 0) {
            try {
                api.setOrganizationSlug(organizationData.slug);
                await api.updateOrganization(organization.id, updateOrganizationDto);
            }
            catch (e) {
                this.log(`Error updating organization ${organizationData.slug}: ${e.response.data.message}`);
            }
        }
        else if (!updatedPhoto) {
            this.log(`No changes to update for the organization ${organizationData.slug}`);
        }
        else {
            this.log(`Organization '${organizationData.slug}' updated`);
        }
    }
    async run() {
        const { args } = await this.parse(OrganizationsSet);
        if (!args.yaml_file.endsWith('.yaml') && !args.yaml_file.endsWith('.yml')) {
            this.error('File is not a yaml file');
        }
        if (!(0, fs_1.existsSync)(args.yaml_file)) {
            this.log(`File ${args.yaml_file} does not exist`);
            return;
        }
        const yamlFileContent = (0, fs_1.readFileSync)(args.yaml_file, 'utf8');
        let organizationsData = null;
        try {
            organizationsData = jsYaml.load(yamlFileContent);
            if (!Array.isArray(organizationsData)) {
                this.error('File is not an array of organizations');
            }
        }
        catch (e) {
            this.error('File is not a valid yaml file');
        }
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        const api = new kyso_store_1.Api();
        api.configure(`${kysoCredentials.kysoInstallUrl}/api/v1`, kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.token);
        const decoded = (0, jwt_decode_1.default)(kysoCredentials.token);
        let tokenPermissions = null;
        try {
            const resultPermissions = await api.getUserPermissions(decoded.payload.username);
            tokenPermissions = resultPermissions.data;
        }
        catch (e) {
            this.error('Error getting user permissions');
        }
        for (const organizationData of organizationsData) {
            if (!organizationData.slug) {
                this.log(`Slug not specified for ${organizationData.display_name ? organizationData.display_name : '?'}. Ignoring it`);
                continue;
            }
            // Slug the organization to ensure that if someone introduced the name of the organization in
            // capital letters we are going to be able to answer properly
            organizationData.slug = helper_1.Helper.slug(organizationData.slug);
            await this.updateOrganization(api, tokenPermissions, organizationData, kysoCredentials);
            this.log(`🎉🎉🎉 Organization ${organizationData.display_name} updated successfully 🎉🎉🎉`);
        }
    }
}
exports.default = OrganizationsSet;
OrganizationsSet.description = 'Pass the organizations configuration values from the yaml_file to the backend and merge its values with the existing ones (that is, missing values keep their value).\nThis command does not get the organization names from the command line because we can pass multiple organizations on the YAML file and each of them includes its name.\nNote that when updating the information of an organization the list of channels is not used, that is, no channel is added or removed with this command, to manage channels you should use the channel subcommand.';
OrganizationsSet.examples = [`$ kyso organization set <yaml_file>`];
OrganizationsSet.args = [
    {
        name: 'yaml_file',
        description: 'Yaml file with organizations data',
        required: true,
    },
];
