"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const kyso_store_1 = require("@kyso-io/kyso-store");
const core_1 = require("@oclif/core");
const axios_1 = tslib_1.__importDefault(require("axios"));
const fs_1 = require("fs");
const jwt_decode_1 = tslib_1.__importDefault(require("jwt-decode"));
const path_1 = require("path");
const interactive_login_1 = require("../../../helpers/interactive-login");
const kyso_command_1 = require("../../kyso-command");
class DownloadProfileBackground extends kyso_command_1.KysoCommand {
    async run() {
        const { flags } = await this.parse(DownloadProfileBackground);
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        const api = new kyso_store_1.Api();
        api.configure(`${kysoCredentials.kysoInstallUrl}/api/v1`, kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.token);
        const decoded = (0, jwt_decode_1.default)(kysoCredentials.token);
        try {
            const result = await api.getUserProfileByUsername(decoded.payload.username);
            const userDTO = result.data;
            if (!userDTO.background_image_url) {
                this.error('User has no photo');
            }
            const imageUrl = userDTO.background_image_url.startsWith('http') ? userDTO.background_image_url : kysoCredentials.kysoInstallUrl + userDTO.background_image_url;
            const axiosResponse = await axios_1.default.get(imageUrl, { responseType: 'arraybuffer' });
            const urlParts = axiosResponse.request.res.responseUrl.split('/');
            if (urlParts.length === 0) {
                this.error('Error downloading photo');
            }
            const fileName = urlParts[urlParts.length - 1];
            if (!fileName.includes('.')) {
                this.error('User profile photo has no extension');
            }
            const filePath = (0, path_1.resolve)((0, path_1.join)(flags.path, fileName));
            (0, fs_1.writeFileSync)(filePath, axiosResponse.data, 'binary');
            this.log(`Photo downloaded to ${filePath}`);
        }
        catch (e) {
            this.error('Error downloading photo');
        }
    }
}
exports.default = DownloadProfileBackground;
DownloadProfileBackground.description = 'Download the background image and save them on the provided image_file.';
DownloadProfileBackground.examples = [`$ kyso profile download background`, `$ kyso profile download background -p <path>`];
DownloadProfileBackground.flags = {
    path: core_1.Flags.string({
        char: 'p',
        description: 'Destination folder in which the photo will be downloaded',
        required: false,
        default: '.',
    }),
};
DownloadProfileBackground.args = [];
