"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const kyso_store_1 = require("@kyso-io/kyso-store");
const fs_1 = require("fs");
const jwt_decode_1 = tslib_1.__importDefault(require("jwt-decode"));
const helper_1 = require("../../../helpers/helper");
const interactive_login_1 = require("../../../helpers/interactive-login");
const kyso_command_1 = require("../../kyso-command");
class UploadBackground extends kyso_command_1.KysoCommand {
    async run() {
        const { args } = await this.parse(UploadBackground);
        // Check if file exists
        if (!(0, fs_1.existsSync)(args.path)) {
            this.log(`File ${args.path} does not exist`);
            return;
        }
        // Check if file is an image
        if (!helper_1.Helper.isImage(args.path)) {
            this.log(`File ${args.path} is not an image. Valid formats are: png, jpg, jpeg, gif`);
            return;
        }
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        const api = new kyso_store_1.Api();
        api.configure(`${kysoCredentials.kysoInstallUrl}/api/v1`, kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.token);
        const decoded = (0, jwt_decode_1.default)(kysoCredentials.token);
        try {
            const readStream = (0, fs_1.createReadStream)(args.path);
            await api.uploadUserBackgroundImage(decoded.payload.id, readStream);
            this.log(`Background uploaded successfully`);
        }
        catch (e) {
            this.log(`Error uploading background profile image: ${e.response.data.message}`);
        }
    }
}
exports.default = UploadBackground;
UploadBackground.description = 'Upload the image_file as the background image.';
UploadBackground.examples = [`$ kyso profile upload background <path>`];
UploadBackground.args = [
    {
        name: 'path',
        required: true,
        description: 'Path to the image',
    },
];
