"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const kyso_store_1 = require("@kyso-io/kyso-store");
const fs_1 = require("fs");
const interactive_login_1 = require("../../helpers/interactive-login");
const kyso_command_1 = require("../kyso-command");
class Add extends kyso_command_1.KysoCommand {
    async run() {
        const { args } = await this.parse(Add);
        // Check if file exists
        if (!(0, fs_1.existsSync)(args.path)) {
            this.log(`File ${args.path} does not exist`);
            return;
        }
        // Check if file is a zip file
        if (!args.path.endsWith('.zip')) {
            this.log(`File ${args.path} is not a zip file`);
            return;
        }
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        const api = new kyso_store_1.Api();
        api.configure(`${kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.kysoInstallUrl}/api/v1`, kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.token);
        try {
            const readStream = (0, fs_1.createReadStream)(args.path);
            await api.uploadTheme(args.name, readStream);
            this.log(`Theme ${args.name} uploaded successfully`);
        }
        catch (e) {
            const errorResponse = e.response.data;
            if (errorResponse.statusCode === 403) {
                this.log(`You don't have permission to upload themes`);
            }
            else {
                this.log(`Error adding theme: ${e.response.data.message}`);
            }
        }
    }
}
exports.default = Add;
Add.description = 'Uploads the <zip_file_path> to the given <theme_name> folder replacing its previous contents.';
Add.examples = [`$ kyso theme add <theme_name> <zip_file_path>`, `$ kyso theme add default default.zip`];
Add.args = [
    {
        name: 'name',
        description: 'Theme name',
        required: true,
    },
    {
        name: 'path',
        description: 'Zipped theme path',
        required: true,
    },
];
