"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const kyso_store_1 = require("@kyso-io/kyso-store");
const interactive_login_1 = require("../../helpers/interactive-login");
const kyso_command_1 = require("../kyso-command");
class Del extends kyso_command_1.KysoCommand {
    async run() {
        const { args } = await this.parse(Del);
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        const api = new kyso_store_1.Api();
        api.configure(`${kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.kysoInstallUrl}/api/v1`, kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.token);
        try {
            await api.deleteTheme(args.name);
            this.log(`\n🎉🎉🎉 Success! Theme deleted 🎉🎉🎉\n`);
        }
        catch (e) {
            const errorResponse = e.response.data;
            if (errorResponse.statusCode === 403) {
                this.log(`You don't have permission to delete themes`);
            }
            else {
                this.log(`Error deleting theme: ${e.response.data.message}`);
            }
        }
    }
}
exports.default = Del;
Del.description = 'Removes the <theme_name> folder.';
Del.examples = [`$ kyso theme del <theme_name>`, `$ kyso theme del default`];
Del.args = [
    {
        name: 'name',
        description: 'Theme name',
        required: true,
    },
];
