"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const kyso_store_1 = require("@kyso-io/kyso-store");
const adm_zip_1 = tslib_1.__importDefault(require("adm-zip"));
const path_1 = require("path");
const interactive_login_1 = require("../../helpers/interactive-login");
const kyso_command_1 = require("../kyso-command");
class Get extends kyso_command_1.KysoCommand {
    async run() {
        const { args } = await this.parse(Get);
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        const api = new kyso_store_1.Api();
        api.configure(`${kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.kysoInstallUrl}/api/v1`, kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.token);
        try {
            const buffer = await api.downloadTheme(args.name);
            const zip = new adm_zip_1.default(buffer);
            const destinationPath = (0, path_1.join)(args.path, args.name);
            zip.extractAllTo(destinationPath, true);
            this.log(`\n🎉🎉🎉 Success! Theme downloaded to ${(0, path_1.resolve)(destinationPath)} 🎉🎉🎉\n`);
        }
        catch (e) {
            const errorResponse = JSON.parse(e.response.data.toString());
            if (errorResponse.statusCode === 403) {
                this.log(`You don't have permission to download themes`);
            }
            else {
                this.log(`Error downloading theme: ${errorResponse.message}`);
            }
        }
    }
}
exports.default = Get;
Get.description = 'Downloads the contents of the theme_name folder and stores it on the given zip_file or on the theme_name.zip file on the current directory if no zip_file is provided.';
Get.examples = [
    `$ kyso theme get <theme_name> <destination_folder>`,
    `$ kyso theme get default .`,
    `$ kyso theme get default ./default-theme          - Note: default-theme folder must exist before running the command`,
];
Get.args = [
    {
        name: 'name',
        description: 'Theme name',
        required: true,
    },
    {
        name: 'path',
        description: 'Path where to save the theme',
        required: false,
        default: '.',
    },
];
