"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const kyso_store_1 = require("@kyso-io/kyso-store");
const interactive_login_1 = require("../../helpers/interactive-login");
const kyso_command_1 = require("../kyso-command");
class Set extends kyso_command_1.KysoCommand {
    async run() {
        const { args } = await this.parse(Set);
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        const api = new kyso_store_1.Api();
        api.configure(`${kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.kysoInstallUrl}/api/v1`, kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.token);
        try {
            await api.setDefaultTheme(args.name);
            this.log(`\n🎉🎉🎉 Success! The theme has been changed 🎉🎉🎉\n`);
            this.log(`\n`);
            this.log(`Remember that users must close and reopen their browser for the changes to take effect.`);
        }
        catch (e) {
            const errorResponse = e.response.data;
            if (errorResponse.statusCode === 403) {
                this.log(`You don't have permission to change the theme`);
            }
            else {
                this.log(`Error changing the theme: ${e.response.data.message}`);
            }
        }
    }
}
exports.default = Set;
Set.description = 'Set the <theme_name> as default.';
Set.examples = [`$ kyso theme set <theme_name>`, `$ kyso theme set default`];
Set.args = [
    {
        name: 'name',
        description: 'Theme name',
        required: true,
    },
];
