"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const kyso_store_1 = require("@kyso-io/kyso-store");
const jwt_decode_1 = tslib_1.__importDefault(require("jwt-decode"));
const helper_1 = require("../../helpers/helper");
const interactive_login_1 = require("../../helpers/interactive-login");
const kyso_command_1 = require("../kyso-command");
class UnsetGlobalAdmin extends kyso_command_1.KysoCommand {
    async unsetUserAsGlobalAdmin(api, email) {
        let userId = null;
        try {
            const userResult = await api.getHttpClient().get(`/users?email=${encodeURIComponent(email)}`);
            const users = userResult.data.data;
            if (users.length === 0) {
                this.error(`User with email '${email}' not found`);
            }
            userId = users[0].id;
        }
        catch (e) {
            // const errorResponse: ErrorResponse = e.response.data;
            this.error('Error getting user');
        }
        try {
            await api.removeUserAsGlobalAdmin(userId);
            this.log(`User with email '${email}' is no longer a global admin`);
        }
        catch (e) {
            // const errorResponse: ErrorResponse = e.response.data;
            this.error('Error setting user as global admin');
        }
    }
    async run() {
        const { args } = await this.parse(UnsetGlobalAdmin);
        if (!helper_1.Helper.isEmail(args.email)) {
            this.log('Invalid email');
            return;
        }
        await (0, interactive_login_1.launchInteractiveLoginIfNotLogged)();
        const kysoCredentials = kyso_command_1.KysoCommand.getCredentials();
        const decoded = (0, jwt_decode_1.default)(kysoCredentials.token);
        const api = new kyso_store_1.Api();
        api.configure(`${kysoCredentials.kysoInstallUrl}/api/v1`, kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.token);
        let tokenPermissions = null;
        try {
            const resultPermissions = await api.getUserPermissions(decoded.payload.username);
            tokenPermissions = resultPermissions.data;
        }
        catch (e) {
            this.error('Error getting user permissions');
        }
        if (!tokenPermissions.global || !helper_1.Helper.isGlobalAdmin(tokenPermissions)) {
            this.error("You don't have permissions unset users as global admins");
        }
        await this.unsetUserAsGlobalAdmin(api, args.email);
    }
}
exports.default = UnsetGlobalAdmin;
UnsetGlobalAdmin.description = 'Unset user as global admin';
UnsetGlobalAdmin.examples = [`How to use: \n\t$ kyso user unset-global-admin <email@kyso.io>`];
UnsetGlobalAdmin.args = [
    {
        name: 'email',
        description: 'User mail to unset as a global admin: email@kyso.io',
        required: true,
    },
];
