"use strict";
/* eslint-disable indent */
Object.defineProperty(exports, "__esModule", { value: true });
exports.interactiveLogin = exports.launchInteractiveLoginIfNotLogged = void 0;
const kyso_model_1 = require("@kyso-io/kyso-model");
const kyso_store_1 = require("@kyso-io/kyso-store");
const inquirer = require("inquirer");
const kyso_command_1 = require("../commands/kyso-command");
const check_credentials_result_enum_1 = require("../types/check-credentials-result.enum");
const helper_1 = require("./helper");
const oauths_1 = require("./oauths");
const launchInteractiveLoginIfNotLogged = async () => {
    var _a;
    const checkCredentialsResult = await kyso_command_1.KysoCommand.checkCredentials();
    switch (checkCredentialsResult) {
        case check_credentials_result_enum_1.CheckCredentialsResultEnum.NOT_EXIST: {
            const login = await (0, exports.interactiveLogin)(kyso_command_1.KysoCommand.getCredentials());
            /**
             * WTF?
             * Argument of type
             * 'import("/home/fjbarrena/Projects/kyso/kyso-cli/node_modules/@kyso-io/kyso-model/dist/models/login.model").Login'
             * is not assignable to parameter of type
             * 'import("/home/fjbarrena/Projects/kyso/kyso-cli/node_modules/@kyso-io/kyso-store/node_modules/@kyso-io/kyso-model/dist/models/login.model").Login'.
             *
             * Casting to any for now
             */
            await kyso_store_1.store.dispatch((0, kyso_store_1.loginAction)(login));
            const { auth, error } = kyso_store_1.store.getState();
            if (auth.token) {
                kyso_command_1.KysoCommand.saveToken(auth.token, null, null, login.kysoInstallUrl, null);
            }
            else {
                throw new Error((_a = error === null || error === void 0 ? void 0 : error.text) !== null && _a !== void 0 ? _a : 'An error occurred making login request');
            }
            break;
        }
        case check_credentials_result_enum_1.CheckCredentialsResultEnum.EXPIRED_TOKEN: {
            try {
                const savedCredentials = kyso_command_1.KysoCommand.getCredentials();
                const api = new kyso_store_1.Api(savedCredentials.token);
                api.configure(`${savedCredentials.kysoInstallUrl}/api/v1`, savedCredentials.token);
                const refreshedToken = await api.refreshToken();
                if (refreshedToken.data) {
                    kyso_store_1.store.dispatch((0, kyso_store_1.setTokenAuthAction)(refreshedToken.data));
                    kyso_command_1.KysoCommand.saveToken(refreshedToken.data, null, null, savedCredentials.kysoInstallUrl, null);
                }
            }
            catch {
                console.error('Error refreshing token. Please run kyso login manually');
            }
            break;
        }
        case check_credentials_result_enum_1.CheckCredentialsResultEnum.VALID: {
            // All right, nothing to do
            break;
        }
        default:
            break;
    }
};
exports.launchInteractiveLoginIfNotLogged = launchInteractiveLoginIfNotLogged;
const interactiveLogin = async (kysoCredentials) => {
    const login = new kyso_model_1.Login('', kyso_model_1.LoginProviderEnum.KYSO, '', null, null);
    if (kysoCredentials === null || kysoCredentials === void 0 ? void 0 : kysoCredentials.fixedKysoInstallUrl) {
        login.kysoInstallUrl = kysoCredentials.fixedKysoInstallUrl;
    }
    else {
        const url = await helper_1.Helper.askUserKysoInstallUrl();
        login.kysoInstallUrl = url;
    }
    const providerResponse = await inquirer.prompt([
        {
            name: 'provider',
            message: 'Select a provider',
            type: 'list',
            choices: [
                { name: 'Kyso', value: kyso_model_1.LoginProviderEnum.KYSO },
                { name: 'Access token', value: kyso_model_1.LoginProviderEnum.KYSO_ACCESS_TOKEN },
                { name: 'Gitlab', value: kyso_model_1.LoginProviderEnum.GITLAB },
                { name: 'Google', value: kyso_model_1.LoginProviderEnum.GOOGLE },
                // { name: 'Bitbucket', value: LoginProviderEnum.BITBUCKET },
                // { name: 'Github', value: LoginProviderEnum.GITHUB },
            ],
        },
    ]);
    login.provider = providerResponse.provider;
    switch (login.provider) {
        case kyso_model_1.LoginProviderEnum.KYSO:
        case kyso_model_1.LoginProviderEnum.KYSO_ACCESS_TOKEN: {
            const emailResponse = await inquirer.prompt([
                {
                    name: 'email',
                    message: 'What is your email?',
                    type: 'input',
                    validate(password) {
                        if (password === '') {
                            return 'Email cannot be empty';
                        }
                        return true;
                    },
                },
            ]);
            login.email = emailResponse.email;
            break;
        }
        default:
            login.email = '';
            break;
    }
    switch (providerResponse.provider) {
        case kyso_model_1.LoginProviderEnum.KYSO: {
            const passwordResponse = await inquirer.prompt([
                {
                    name: 'password',
                    message: 'What is your password?',
                    type: 'password',
                    mask: '*',
                    validate(password) {
                        if (password === '') {
                            return 'Password cannot be empty';
                        }
                        return true;
                    },
                },
            ]);
            login.password = passwordResponse.password;
            break;
        }
        case kyso_model_1.LoginProviderEnum.KYSO_ACCESS_TOKEN: {
            const accessTokenResponse = await inquirer.prompt([
                {
                    name: 'accessToken',
                    message: `What is your access token (Get one from ${login.kysoInstallUrl}/settings )?`,
                    type: 'accessToken',
                    mask: '*',
                    validate(accessToken) {
                        if (accessToken === '') {
                            return 'Access token cannot be empty';
                        }
                        return true;
                    },
                },
            ]);
            login.password = accessTokenResponse.accessToken;
            break;
        }
        case kyso_model_1.LoginProviderEnum.GOOGLE: {
            const googleResult = await (0, oauths_1.authenticateWithGoogle)(login.kysoInstallUrl);
            if (googleResult.errorMessage) {
                throw new Error(googleResult.errorMessage);
            }
            login.password = googleResult.code;
            login.payload = googleResult.redirectUrl;
            break;
        }
        case kyso_model_1.LoginProviderEnum.GITHUB: {
            const githubResult = await (0, oauths_1.authenticateWithGithub)(login.kysoInstallUrl);
            if (githubResult.errorMessage) {
                throw new Error(githubResult.errorMessage);
            }
            login.password = githubResult.code;
            break;
        }
        case kyso_model_1.LoginProviderEnum.BITBUCKET: {
            const bitbucketResult = await (0, oauths_1.authenticateWithBitbucket)(login.kysoInstallUrl);
            if (bitbucketResult.errorMessage) {
                throw new Error(bitbucketResult.errorMessage);
            }
            login.password = bitbucketResult.code;
            break;
        }
        case kyso_model_1.LoginProviderEnum.GITLAB: {
            const gitlabResponse = await (0, oauths_1.authenticateWithGitlab)(login.kysoInstallUrl);
            if (gitlabResponse.errorMessage) {
                throw new Error(gitlabResponse.errorMessage);
            }
            login.password = gitlabResponse.code;
            login.payload = gitlabResponse.redirectUrl;
            break;
        }
        default:
            throw new Error('No provider selected');
            break;
    }
    if (login.kysoInstallUrl) {
        process.env.KYSO_API = `${login.kysoInstallUrl}/api/v1`;
    }
    return login;
};
exports.interactiveLogin = interactiveLogin;
